* FROM: http://www.ats.ucla.edu/stat/sas/dae/ologit.htm;

* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=MAX formdlim=' ' spool; 									
* Kill default titles on output, ODS tables in log, turn on graphics; 
TITLE; ODS TRACE OFF; ODS LISTING; ODS GRAPHICS ON;

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR EXAMPLE 9                *******
*******             CHANGE "filesave" to your directory                  *******
********************************************************************************

* Location for original files for these models  change this path;
%LET filesave= C:\Dropbox\14_SPLH861\861_Example9; 
LIBNAME filesave "&filesave.";

* Send data to STATA;
PROC EXPORT DATA=filesave.ologit OUTFILE="&filesave.\ologit.dta" DBMS=STATA REPLACE; RUN;

* Creating formats for categorical variables;
PROC FORMAT; 
    VALUE F2apply   0="0No" 1="1Pry";
    VALUE FparentGD 0="0NoDegree" 1="1YesDegree";
    VALUE Fprivate  0="0public" 1="1private";
RUN;
* Import data into work library, transform variables, apply value formats;
DATA work.ologit; SET filesave.ologit;
	IF apply=0 THEN apply2=0;
	IF apply>0 THEN apply2=1;
    parentGD=pared;
    GPA3=GPA-3;
         IF public=1 THEN private=0; 
    ELSE IF public=0 THEN private=1;
    ELSE IF public=. THEN private=.;
    LABEL apply=    "apply: 0=Not, 1=Eh, 2=Very"
		  apply2=   "apply2: 0=No, 1=Pry"
          parentGD= "parentGD: Parent Has Graduate Degree (0=N,1=Y)"
          private=  "private: Student Attends Private University (0=N,1=Y)"
          GPA3=     "GPA3: Student GPA (0=3)";  
	FORMAT apply2 F2apply. parentGD FparentGD. private Fprivate.;
RUN;

********************************************************************************
******                    BEGIN EXAMPLE 9 MODELS						 *******
********************************************************************************

* Open output directory to save results to;
ODS RTF FILE="&filesave.\SAS_Example9_Output.rtf" STYLE=HTMLBlue STARTPAGE=NO;

TITLE1 "DESCRIPTIVES FOR STUDY VARIABLES";
PROC MEANS DATA=work.ologit; 
     VAR GPA; 
RUN;
PROC FREQ DATA=work.ologit;
     TABLE apply2 parentGD private; 
RUN; TITLE1;

TITLE1 "EMPTY MODEL PREDICTING BINARY DV";
PROC GLIMMIX DATA=work.ologit NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL apply2 (DESCENDING) = / SOLUTION LINK=LOGIT DIST=BINARY;
* ILINK requests logit estimate to be transformed into probability;
  ESTIMATE "Intercept" intercept 1 / ILINK;
RUN; TITLE1; 

TITLE1 "MAIN EFFECTS MODEL PREDICTING BINARY DV";
PROC GLIMMIX DATA=work.ologit NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  CLASS parentGD private;
  MODEL apply2 (DESCENDING) = GPA3 parentGD private / SOLUTION LINK=LOGIT DIST=BINARY ODDSRATIO(AT GPA3=0);
  ESTIMATE "Intercept for No Degree,  Public,  GPA=2" intercept 1 GPA3 -1 parentGD 1 0 private 1 0 / ILINK;
  ESTIMATE "Intercept for No Degree,  Private, GPA=2" intercept 1 GPA3 -1 parentGD 1 0 private 0 1 / ILINK;
  ESTIMATE "Intercept for Yes Degree, Public,  GPA=2" intercept 1 GPA3 -1 parentGD 0 1 private 1 0 / ILINK;
  ESTIMATE "Intercept for Yes Degree, Private, GPA=2" intercept 1 GPA3 -1 parentGD 0 1 private 0 1 / ILINK;
  ESTIMATE "Intercept for No Degree,  Public,  GPA=3" intercept 1 GPA3  0 parentGD 1 0 private 1 0 / ILINK;
  ESTIMATE "Intercept for No Degree,  Private, GPA=3" intercept 1 GPA3  0 parentGD 1 0 private 0 1 / ILINK;
  ESTIMATE "Intercept for Yes Degree, Public,  GPA=3" intercept 1 GPA3  0 parentGD 0 1 private 1 0 / ILINK;
  ESTIMATE "Intercept for Yes Degree, Private, GPA=3" intercept 1 GPA3  0 parentGD 0 1 private 0 1 / ILINK;
  ESTIMATE "Intercept for No Degree,  Public,  GPA=4" intercept 1 GPA3  1 parentGD 1 0 private 1 0 / ILINK;
  ESTIMATE "Intercept for No Degree,  Private, GPA=4" intercept 1 GPA3  1 parentGD 1 0 private 0 1 / ILINK;
  ESTIMATE "Intercept for Yes Degree, Public,  GPA=4" intercept 1 GPA3  1 parentGD 0 1 private 1 0 / ILINK;
  ESTIMATE "Intercept for Yes Degree, Private, GPA=4" intercept 1 GPA3  1 parentGD 0 1 private 0 1 / ILINK;
  ESTIMATE "Slope for GPA" GPA3 1 / ILINK; * Example of non-sense ILINK for a slope; 
RUN; TITLE1; 

TITLE1 "INTERACTIONS MODEL PREDICTING BINARY DV";
PROC GLIMMIX DATA=work.ologit NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  CLASS parentGD private;
  MODEL apply2 (DESCENDING) = GPA3|parentGD|private@2 / SOLUTION LINK=LOGIT DIST=BINARY ODDSRATIO(AT GPA3=0);
 * Conditional means for plotting interactions, SLICEDIFF gives simple effects;
  LSMEANS parentGD|private / ILINK SLICEDIFF=parentGD SLICEDIFF=private AT(GPA3)=(-1); * At GPA=2;
  LSMEANS parentGD|private / ILINK SLICEDIFF=parentGD SLICEDIFF=private AT(GPA3)=( 0); * At GPA=3;
  LSMEANS parentGD|private / ILINK SLICEDIFF=parentGD SLICEDIFF=private AT(GPA3)=( 1); * At GPA=4;
* Simple slopes for GPA and slope differences by moderators;
  ESTIMATE "GPA Slope for No  Degree for Public School"  GPA3 1 GPA3*parentGD  1 0 GPA3*private  1 0;
  ESTIMATE "GPA Slope for Yes Degree for Public School"  GPA3 1 GPA3*parentGD  0 1 GPA3*private  1 0;
  ESTIMATE "GPA Slope for No  Degree for Private School" GPA3 1 GPA3*parentGD  1 0 GPA3*private  0 1;
  ESTIMATE "GPA Slope for Yes Degree for Private School" GPA3 1 GPA3*parentGD  0 1 GPA3*private  0 1;
  ESTIMATE "GPA Slope Degree Diff"                              GPA3*parentGD -1 1                  ;
  ESTIMATE "GPA Slope School Diff"                                                 GPA3*private -1 1;
RUN; TITLE1; 

* Close output;
ODS RTF CLOSE; 


