* Prevent "more" messages from appearing
set more off, permanently
* Control line length
set linesize 150

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR EXAMPLE 9                *******
*******             CHANGE "filesave" to your directory                  *******
********************************************************************************

* Defining global variable for file location to be replaced in code below
global filesave "C:\Dropbox\14_SPLH861\861_Example9"
 
* Import data, transform variables, apply value formats
use "$filesave\ologit.dta", clear
gen apply2=0
recode apply2 (0=1) if apply==1
recode apply2 (0=1) if apply==2
gen parentgd=pared
gen gpa3=gpa-3
gen private=0
recode private (0=1) if public==0
label variable apply    "apply: 0=Not, 1=Eh, 2=Very"
label variable apply2   "apply2: 0=No, 1=Pry"
label variable parentgd "parentgd: Parent Has Graduate Degree (0=N,1=Y)"
label variable private  "private: Student Attends Private University (0=N,1=Y)"
label variable gpa3     "gpa3: Student GPA (0=3)"
label define f2apply     0 "0No" 1 "1Pry"
label define fparentgd   0 "0NoDegree" 1 "1YesDegree"
label define fprivate    0 "0public" 1 "1private"
label values apply2 f2apply
label values parentgd fparentgd
label values private fprivate
 
********************************************************************************
******                    BEGIN EXAMPLE 9 MODELS						 *******
********************************************************************************

* Save results to separate file
log using $filesave\STATA_Example9_Output.log, replace name(STATA_Example9)
 
display as result "DESCRIPTIVES FOR STUDY VARIABLES"
summarize gpa
tabulate apply2
tabulate parentgd
tabulate private

display as result "EMPTY MODEL PREDICTING BINARY DV"
melogit apply2 ,  
	estat ic, n(400),
	nlcom 1/(1+exp(-1*(_b[_cons]))) // intercept in probability

display as result "MAIN EFFECTS MODEL PREDICTING BINARY DV"
melogit apply2 c.gpa3 ib(last).parentgd ib(last).private,
    estat ic, n(400),
	margins i.parentgd, over(i.private) at(c.gpa3=(-1(1)1)) predict(xb) // logits
    margins i.parentgd, over(i.private) at(c.gpa3=(-1(1)1))             // probabilities	
	
* must re-run with 'or' added to first line to get odds ratios
display as result "MAIN EFFECTS MODEL PREDICTING BINARY DV"
display as result "ODDS RATIOS INSTEAD OF LOGITS"
melogit apply2 c.gpa3 ib(last).parentgd ib(last).private, or,
    estat ic, n(400),
	margins i.parentgd, over(i.private) at(c.gpa3=(-1(1)1)) predict(xb) // logits
    margins i.parentgd, over(i.private) at(c.gpa3=(-1(1)1))             // probabilities	
	
display as result "INTERACTIONS EFFECTS MODEL PREDICTING BINARY DV"
melogit apply2 c.gpa3 ib(last).parentgd ib(last).private ///
               c.gpa3#ib(last).parentgd c.gpa3#ib(last).private ///
			   ib(last).parentgd#ib(last).private,
    estat ic, n(400),
	margins i.parentgd#i.private, at(c.gpa3=(-1(1)1)) predict(xb) // logits
	margins i.parentgd#i.private, at(c.gpa3=(-1(1)1))             // probabilities
	margins i.private@i.parentgd, at(c.gpa3=(-1(1)1)) predict(xb) // simple effects in logits
	margins i.parentgd@i.private, at(c.gpa3=(-1(1)1)) predict(xb) // simple effects in logits
	lincom c.gpa3*1 + c.gpa3#i0.parentgd*1 + c.gpa3#i0.private // GPA slope for no degree, public
	lincom c.gpa3*1 + c.gpa3#i1.parentgd*1 + c.gpa3#i0.private // GPA slope for yes degree, public
	lincom c.gpa3*1 + c.gpa3#i0.parentgd*1 + c.gpa3#i1.private // GPA slope for no degree, private
	lincom c.gpa3*1 + c.gpa3#i1.parentgd*1 + c.gpa3#i1.private // GPA slope for yes degree, private
	
* Close log	
log close STATA_Example9
